{% if show %}
<div>
    <ul class="toplinks">
    {% block date-hierarchy-toplinks %}
        {% block date-hierarchy-back %}
            {% if back %}<li class="date-back"><a href="{{ back.link }}">&lsaquo; {{ back.title }}</a></li>{% endif %}
        {% endblock %}
        {% block date-hierarchy-choices %}
        {% for choice in choices %}
        <li> {% if choice.link %}<a href="{{ choice.link }}">{% endif %}{{ choice.title }}{% if choice.link %}</a>{% endif %}</li>
        {% endfor %}
        {% endblock %}
    {% endblock %}
    </ul>
</div>
{% endif %}
