{% load i18n %}
<div>
	<h4>{% trans "Summary" %}</h4>
	<ul class="uk-list uk-list-disc uk-list-primary">
		{% for model_name, object_count in model_count %}
		<li>{{ model_name|capfirst }}: {{ object_count }}</li>
		{% endfor %}
	</ul>
</div>