{% load uikit_admin %}
	<div class="uk-panel uk-panel-header uk-panel-box uk-panel-box-secondary uk-margin-bottom">
		<div class="module aligned {{ fieldset.classes }} uk-form-stacked">
			{% if fieldset.name %}<h4 class="uk-heading-line"><span>{{ fieldset.name }}</span></h4>{% endif %}
			{% if fieldset.description %}
				<div class="description">{{ fieldset.description|safe }}</div>
			{% endif %}
			{% for line in fieldset %}
				<div class="{% if line.fields|length_is:'1' and line.errors %} errors{% endif %}
							{% if not line.has_visible_field %} hidden{% endif %}
							{% for field in line %}{% if field.field.name %} field-{{ field.field.name }}{% endif %}{% endfor %}
							" {% if line.fields|length > 1 %}uk-grid{% endif %}>
							
					{% for field in line %}
						<div{% if not line.fields|length_is:'1' %}
							class="field-box{% if field.field.name %} field-{{ field.field.name }}{% endif %}{% if not field.is_readonly and field.errors %} errors{% endif %}{% if field.field.is_hidden %} hidden{% endif %}"
							{% elif field.is_checkbox %}
							class="checkbox-row"
							{% endif %}>
							{% if field.is_checkbox %}
									<label class="uk-form-label">
									{% uk_element field.field "uk-checkbox" %}
									<span class="uk-form-help-inline">{{ field.field.label }}</span></label>
							{% else %}
								{% if field.is_readonly %}
									{{ field.label_tag }}
									<p>{{ field.contents }}</p>
								{% else %}
									{% uka_form_row_stacked field.field field.field.errors %}{# uk-form-width-large #}
								{% endif %}
							{% endif %}
						</div>
					{% endfor %}
				</div>
			{% endfor %}
		</div>
	</div>