{% load i18n admin_urls %}

{% block object-tools-items %}
<div class="uk-float-right">
	  <ul class="uk-subnav uk-subnav-pill uk-padding-small uk-margin-remove">
		{% if has_add_permission %}
		  <li>
		  {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
			<a href="{% add_preserved_filters history_url %}" class="historylink"><span uk-icon="icon: history"></span> {% trans "History" %}</a>
		  </li>
		{% endif %}
		{% if has_absolute_url %}<li><a href="{{ absolute_url }}"><span uk-icon="icon: link"></span> {% trans "View on site" %}</a></li>{% endif %}
	</ul>
</div>
{% endblock %}