{% load i18n admin_urls %}
<div class="submit-row">
{% block submit-row %}
		
	{% if show_delete_link and original %}
		{% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
		<p class="deletelink-box">
			<a href="{% add_preserved_filters delete_url %}" class="uk-button uk-button-danger">{% trans "Delete" %}</a>
		</p>
	{% endif %}

{% if show_save_as_new %}
	<input type="submit" class="uk-button uk-button-primary" value="{% trans 'Save as new' %}" name="_saveasnew">
{% endif %}

{% if show_save_and_add_another %}
	<input type="submit" class="uk-button uk-button-default" value="{% trans 'Save and add another' %}" name="_addanother">
{% endif %}

{% if show_save_and_continue %}
	<input type="submit" class="uk-button uk-button-default" value="{% if can_change %}{% trans 'Save and continue editing' %}{% else %}{% trans 'Save and view' %}{% endif %}" name="_continue">
{% endif %}

{% if show_save %}<input type="submit" value="{% trans 'Save' %}" class="uk-button uk-button-primary" name="_save">{% endif %}

{% if show_close %}<a href="{% url opts|admin_urlname:'changelist' %}" class="closelink">{% trans 'Close' %}</a>{% endif %}
{% endblock %}
</div>
