{% extends "admin/base_site.html" %}
{% load i18n static uikit_admin %}
{% block userlinks %}{% url 'django-admindocs-docroot' as docsroot %}{% if docsroot %}<a href="{{ docsroot }}">{% trans 'Documentation' %}</a> / {% endif %} {% trans 'Change password' %} / <a href="{% url 'admin:logout' %}">{% trans 'Log out' %}</a>{% endblock %}
{% block breadcrumbs %}
<ul class="uk-breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
    <li><span>{% trans 'Password change' %}</span></li>
</ul>
{% endblock %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
<div class="uk-clearfix uk-background-muted uk-padding-remove">
	<div class="uk-container" uk-height-match>
		<div class="uk-float-left uk-padding-small uk-padding-remove-horizontal uk-flex uk-flex-middle">
			<span class="uk-text-lead">{% trans 'Password change' %}</span>
		</div>
	</div>
</div>

<div class="uk-container uk-padding-small">

<form method="post">{% csrf_token %}
{% if form.errors %}
<div class="uk-alert-danger" uk-alert>
    <a class="uk-alert-close" uk-close></a>
    <p>{% if form.errors.items|length == 1 %}{% trans "Please correct the error below." %}{% else %}{% trans "Please correct the errors below." %}{% endif %}</p>
</div>
{{ form.olderrors }}
{% endif %}

<p>{% trans 'Please enter your old password, for security’s sake, and then enter your new password twice so we can verify you typed it in correctly.' %}</p>

<div class="uk-panel uk-panel-header uk-panel-box uk-panel-box-secondary uk-margin-bottom">
	<div class="module aligned uk-form-horizontal">
		{% uka_form_row_stacked form.old_password form.old_password.errors 'uk-form-width-large' %}
		{% uka_form_row_stacked form.new_password1 form.new_password1.errors 'uk-form-width-large' %}
		{% uka_form_row_stacked form.new_password2 form.new_password2.errors 'uk-form-width-large' %}
	</div>
</div>

<div class="submit-row">
    <input type="submit" value="{% trans 'Change my password' %}" class="uk-button uk-button-primary">
</div>

</form></div>

{% endblock %}
