{% extends "admin/base.html" %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="uk-breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
</ul>
{% endblock %}

{% block content_base %}
<div class="uk-container uk-padding uk-padding-remove-horizontal">
	<h1 class="uk-heading-bullet">{% trans 'Logout successful' %}</h1>
	<p>{% trans "Thanks for spending some quality time with the Web site today." %}</p>
	<p><a class="uk-button uk-button-default" href="{% url 'admin:index' %}">{% trans 'Log in again' %}</a></p>
</div>
{% endblock %}
