{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs %}
{% include 'admin/widgets/breadcrumbs_change_password.html' %}
{% endblock %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1>{{ title }}</h1>{% endblock %}

{% block content %}
<div class="uk-container uk-padding uk-padding-remove-horizontal">
	<h1 class="uk-heading-bullet">{% trans 'Password reset' %}</h1>	
	<p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
	<p><a class="uk-button uk-button-default" href="{% url 'admin:index' %}">{% trans 'Log in' %}</a></p>
</div>
{% endblock %}
