{% load i18n static %}
{% if cl.search_fields %}

{# TODO - Put this search form on change_list.html like a satellite form; use admin_changelist.js in order to send search to parent form #}
<div class="uk-width-expand@s">
	<div class="uk-inline uk-width-1-1">
		<a class="uk-form-icon uk-form-icon-flip prl-search-do" uk-icon="icon: search"></a>
		<input class="uk-input uk-width-1-1 prl-search" value="{{ cl.query }}" type="text" placeholder="{% trans 'Search' %}">
	</div>
	<div class="">
		{% if show_result_count %}
			<span class="small quiet">{% blocktrans count counter=cl.result_count %}{{ counter }} result{% plural %}{{ counter }} results{% endblocktrans %} (<a href="?{% if cl.is_popup %}_popup=1{% endif %}">{% if cl.show_full_result_count %}{% blocktrans with full_result_count=cl.full_result_count %}{{ full_result_count }} total{% endblocktrans %}{% else %}{% trans "Show all" %}{% endif %}</a>)</span>
		{% endif %}
	</div>
</div>

{% comment %}
<div id="toolbar">
	<form id="changelist-search" method="get">
		<div><!-- DIV needed for valid HTML -->
			<label for="searchbar"><img src="{% static "admin/img/search.svg" %}" alt="Search"></label>
			<input type="text" size="40" name="{{ search_var }}" value="{{ cl.query }}" id="searchbar" autofocus>
			<input type="submit" value="{% trans 'Search' %}">

			{% if show_result_count %}
    			<span class="small quiet">{% blocktrans count counter=cl.result_count %}{{ counter }} result{% plural %}{{ counter }} results{% endblocktrans %} (<a href="?{% if cl.is_popup %}_popup=1{% endif %}">{% if cl.show_full_result_count %}{% blocktrans with full_result_count=cl.full_result_count %}{{ full_result_count }} total{% endblocktrans %}{% else %}{% trans "Show all" %}{% endif %}</a>)</span>
			{% endif %}

			{% for pair in cl.params.items %}
    			{% if pair.0 != search_var %}<input type="hidden" name="{{ pair.0 }}" value="{{ pair.1 }}">{% endif %}
			{% endfor %}
		</div>
	</form>
</div>
{% endcomment %}
{% endif %}
