{% extends "admin/base_site.html" %}
{% load i18n static %}

{% comment %}
{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/dashboard.css" %}">{% endblock %}
{% endcomment %}

{% block bodyclass %}{{ block.super }} dashboard{% endblock %}

{% block breadcrumbs %}
<ul class="uk-breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
</ul>
{% endblock %}

{% block content %}
<div class="uk-container">
{% if admin.index.template_name %}
	{% include admin.index.template_name %}
{% else %}
	{% if admin.index.show_apps %}
		{% include 'admin/includes/available_apps_index.html' %}
	{% endif %}
{% endif %}
</div>
{% endblock %}

{% block extrastyle %}
<style type="text/css"></style>
{% endblock %}