<div class="datetime" uk-grid>
  <div>{% with widget=widget.subwidgets.0 %}{% include widget.template_name %}{% endwith %}</div>
  <div>{% with widget=widget.subwidgets.1 %}{% include widget.template_name %}{% endwith %}</div>
</div>