"use strict";$(function(){function t(e){$("#searchbar").val(e),$("#changelist-search").get(0).submit()}$(".prl-filter-select").on("change",function(e){window.location=e.target.value}),$("select[name=action]").on("change",function(e){""!=e.target.value&&confirm(gettext("Are you sure?"))&&$(e.target).parents("form")[0].submit()}),$(".prl-search").on("keypress",function(e){if(13==e.which)return t(e.target.value),!1}),$(".prl-search-do").on("click",function(e){t($(e.currentTarget).parent().find("input")[0].value)})});