{% load i18n static %}

{% block userlinks %}
    {% if site_url %}
        <li><a href="{{ site_url }}"><span class="uk-margin-small-right" uk-icon="icon: home"></span> {% trans 'View site' %}</a></li>
    {% endif %}
    {% if user.is_active and user.is_staff %}
        {% url 'django-admindocs-docroot' as docsroot %}
        {% if docsroot %}
            <li><a href="{{ docsroot }}"><span class="uk-margin-small-right" uk-icon="icon: file-text"></span> {% trans 'Documentation' %}</a></li>
        {% endif %}
    {% endif %}
    {% if user.has_usable_password %}
        <li><a href="{% url 'admin:password_change' %}"><span class="uk-margin-small-right" uk-icon="icon: lock"></span> {% trans 'Change password' %}</a></li>
    {% endif %}
    <li class="uk-nav-header"></li>
    <li><a href="{% url 'admin:logout' %}"><span class="uk-margin-small-right" uk-icon="icon: sign-out"></span> {% trans 'Log out' %}</a></li>
{% endblock %}
