{% extends "admin/base_site.html" %}
{% load i18n %}
{% block userlinks %}{% url 'django-admindocs-docroot' as docsroot %}{% if docsroot %}<a href="{{ docsroot }}">{% trans 'Documentation' %}</a> / {% endif %}{% trans 'Change password' %} / <a href="{% url 'admin:logout' %}">{% trans 'Log out' %}</a>{% endblock %}
{% block breadcrumbs %}
<ul class="uk-breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
    <li><span>{% trans 'Password change' %}</span></li>
</ul>
{% endblock %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1>{{ title }}</h1>{% endblock %}
{% block content %}
<div class="uk-container uk-padding uk-padding-remove-horizontal">
	<h1 class="uk-heading-bullet">{% trans 'Password reset' %}</h1>	
	<p>{% trans 'Your password was changed.' %}</p>
	<p><a class="uk-button uk-button-default" href="{% url 'admin:index' %}">{% trans 'Home' %}</a></p>
</div>
{% endblock %}
