{% load admin_list %}
{% load i18n %}
<div class="uk-padding-small uk-margin-top uk-text-center">
	<p class="paginator">
	{% if pagination_required %}
		{% for i in page_range %}
			{% paginator_number cl i %}
		{% endfor %}
	{% endif %}

	<div class="total">
		{{ cl.result_count }} {% if cl.result_count == 1 %}{{ cl.opts.verbose_name }}{% else %}{{ cl.opts.verbose_name_plural }}{% endif %}
	</div>
	{% if show_all_url %}&nbsp;&nbsp;<a href="{{ show_all_url }}" class="showall">{% trans 'Show all' %}</a>{% endif %}
	{% if cl.formset and cl.result_count %}<input type="submit" name="_save" class="default" value="{% trans 'Save' %}">{% endif %}
	</p>
</div>