{% extends "admin/base_site.html" %}
{% load i18n admin_urls static %}

{% block extrahead %}
    {{ block.super }}
    {{ media }}
    <script type="text/javascript" src="{% static 'admin/js/cancel.js' %}"></script>
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} delete-confirmation{% endblock %}

{% block breadcrumbs %}
<ul class="uk-breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
    <li><a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a></li>
    <li>{% if has_view_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}</li>
    <li><a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a></li>
    <li><span>{% trans 'Delete' %}</span></li>
</ul>
{% endblock %}

{% block content %}
<div class='uk-container uk-padding'>
<h3><span uk-icon="icon: warning; ratio: 2"></span></h3>

{% if perms_lacking %}
    <p>{% blocktrans with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}</p>
    <ul class="uk-list uk-list-disc uk-list-primary">
    {% for obj in perms_lacking %}
        <li>{{ obj }}</li>
    {% endfor %}
    </ul>
{% elif protected %}
    <p>{% blocktrans with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would require deleting the following protected related objects:{% endblocktrans %}</p>
    <ul class="uk-list uk-list-disc uk-list-primary">
    {% for obj in protected %}
        <li>{{ obj }}</li>
    {% endfor %}
    </ul>
{% else %}
    <p>{% blocktrans with escaped_object=object %}Are you sure you want to delete the {{ object_name }} "{{ escaped_object }}"? All of the following related items will be deleted:{% endblocktrans %}</p>
    
    <div class="uk-card uk-card-default uk-card-body uk-width-1-2@m uk-margin uk-margin-bottom">
		<div class="uk-grid-large uk-grid uk-grid-divider" uk-grid>
		
		
		<div>
		<h4>{% trans "Objects" %}</h4>
		<ul class="uk-list uk-list-disc uk-list-primary">{{ deleted_objects|unordered_list }}</ul>
		<form method="post">{% csrf_token %}
		</div>
		
		{% include "admin/includes/object_delete_summary.html" %}

		</div>
    </div>
    
    <div>
    <input type="hidden" name="post" value="yes">
    {% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1">{% endif %}
    {% if to_field %}<input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}">{% endif %}
    <input type="submit" class="uk-button uk-button-danger" value="{% trans 'Yes, I’m sure' %}">
    <a href="#" class="uk-button uk-button-default cancel-link">{% trans "No, take me back" %}</a>
    </div>
    </form>
{% endif %}
</div>
{% endblock %}
