{% extends "admin/index.html" %}
{% load i18n %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
    <ul class="uk-breadcrumb">
        <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a></li>
        <li><span>{{ app_list.0.name }}</span></li>
    </ul>
{% endblock %}
{% endif %}

{% block content %}
<div class="uk-container uk-padding">

{% include 'admin/includes/available_apps_index.html' %}

</div>
{% endblock %}